@@ -185,7 +185,8 @@ class MultiShotMemorySampler(Sampler):
 
         batch_x = []
         batch_y = []
-        for idx in idxs:
+        # strip examples if needed. This might happen due to rounding
+        for idx in idxs[:self.batch_size]:
             batch_x.append(self._x[idx])
             batch_y.append(self._y[idx])
 
@@ -332,6 +333,11 @@ class SingleShotMemorySampler(Sampler):
         y = tf.convert_to_tensor([int(i) for i in idxs])
         x = tf.convert_to_tensor([self._x[idx] for idx in y])
 
+        # strip examples if needed. This might happen due to rounding
+        if len(x) > self.batch_size:
+            x = x[:self.batch_size]
+            y = y[:self.batch_size]
+
         return x, y
 
     def get_slice(
